@@ -10,8 +10,8 @@ from jhsp.preprocessing.codingdata import Codingdata
 import configparser
 
 
-
 # 定义SANN类
+# # 在调用时实例化，因为要传入一个工作目录
 class Sann():
     def __init__(self,input_path,task_name_list):
 
@@ -42,13 +42,21 @@ class Sann():
         self.data_utils = data_utils.utils
         self.model_utils = model_utils.utils
 
-# 实例化sann
-# 在调用时实例化，因为要传入一个工作目录
+class Preprocessing():
+    def __init__(self):
+        from jhsp.preprocessing import codingdata
+        from jhsp.preprocessing import describingdata
+        from jhsp.preprocessing import processingdata
+        self.CodingData = codingdata.CodingData
+        self.DescribingData = describingdata.DescribingData
+        self.ProcessingData = processingdata.ProcessingData
 
 
 
-
-
+class Tools():
+    def __init__(self):
+        from jhsp.tools import collatingwords
+        self.CollatingWords = collatingwords.CollatingWords
 
 
 
