@@ -11,13 +11,14 @@ sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 # 这个警告信息可以忽略。
 warnings.filterwarnings(action='ignore',message='elementwise comparison failed')
 
-class Codingdata():
+class CodingData():
     """
     这是一个编码数据的类，包括将one数据转换为onehot数据，将onehot数据转化为one数据，编码分类信息，编码等级信息等。
     本类中所有函数的参数都以列表形式传入。
     """
     def __init__(self, old_dir):
         self.data = self.data = pd.read_excel(old_dir,header=0)   # 第一行默认为表头，数据第一行必须有表头
+        self.data.dropna(axis=0,how='all',inplace=True)  # 删除excel结尾处有可能的出现的无效行
         self.save_dir = os.path.dirname(old_dir)       # 默认保存路径为原数据同一目录
 
     def onehot2one(self,columns):
@@ -93,7 +94,7 @@ class Codingdata():
 
         coded_relationship = []
         for i,y_name in enumerate(y_names):
-            self.data.loc[self.data[y_column[0]]==y_name,[y_name]] = i
+            self.data.loc[self.data[y_column[0]]==y_name,[y_column[0]]] = i
             coded_relationship.append((i, y_name))
 
         save_dir = os.path.join(self.save_dir,'coded_relationship.txt')
